# Characterization
The `characterization` module includes standard implementations for complex characterization protocols.

## Sub-modules
It includes:

* [Two Qubit RB](two_qubit_rb/README.md) - This library includes an efficient implementation of 2-qubit Randomized Benchmarking, enabling measurement of the 2-qubit Clifford gate fidelity and interleaved gate fidelity.
